@@ -16,7 +16,7 @@ triangles<-function(tri.obj)
                  lct=integer(tri.obj$nc),
                  ier=as.integer(0),
                  PACKAGE = "tripack")
-  ret<-matrix(ans$tltri,nt,9,byrow=T)
+  ret<-matrix(ans$tltri,nt,9,byrow=TRUE)
   colnames(ret)<-c("node1","node2","node3","tr1","tr2","tr3","arc1","arc2","arc3")
   ret
 }
